iterateBMAglm.train.predict.test (train.expr.set, test.expr.set, train.class, test.class, p=100, nbest=10, maxNvar=30, maxIter=20000, thresProbne0=1)ExpressionSet object.
We assume the rows in the expression data represent variables (genes),
while the columns represent
samples or experiments. This training data is used to
select relevant genes (variables) for classification.ExpressionSet object.
We assume the rows in the expression data represent variables (genes),
while the columns represent samples or experiments.
The variables selected using the
training data is used to classify samples on this test data.bic.glm in the BMA package.
The default is 10.bic.glm from the BMA package.
The default is 30.bic.glm. The default is 20000.bic.glm. The default
is 1 percent.bic.glm algorithm
from the BMA package. The prediction phase uses the variables
(genes) selected in the training phase to classify the samples
in the test set. The testing phase assumes that the class labels
of the samples in the test set are known, and computes the number of
classification errors and the Brier Score.Yeung, K.Y., Bumgarner, R.E. and Raftery, A.E. (2005) Bayesian Model Averaging: Development of an improved multi-class, gene selection and classification tool for microarray data. Bioinformatics 21: 2394-2402.
iterateBMAglm.train,
iterateBMAglm.train.predict
library (Biobase)
library (BMA)
library (iterativeBMA)
data(trainData)
data(trainClass)
data (testData)
data (testClass)
iterateBMAglm.train.predict.test (train.expr.set=trainData, test.expr.set=testData, trainClass, testClass, p=100)
Run the code above in your browser using DataLab