iterateBMAsurv.train.predict.assess (train.dat, test.dat, surv.time.train, surv.time.test, cens.vec.train, cens.vec.test, p=100, nbest=10, maxNvar=25, maxIter=200000, thresProbne0=1, cutPoint=50, verbose = FALSE, suff.string="")iterateBMAsurv.train.wrapper.bic.surv algorithm. This number is
assumed to be less than the total number of genes in the training data.
A larger p usually requires longer computational time as more iterations
of the bic.surv algorithm are potentially applied. The default is
100.bic.surv in the BMA package.
The default is 10.bic.surv from the BMA package.
The default is 25.bic.surv.
The default is 200000.bic.surv. The default
is 1 percent.success is returned as FALSE.If both risk groups are present in the
patient test samples, a Kaplan-Meier Survival Analysis Curve is written to file,
and a list with 6 components is returned:bic.surv.bic.surv.survdiff that contains the statistics
from survival analysis, including the variance matrix, chi-square
statistic, and p-value.bic.surv
algorithm from the BMA package. The prediction phase uses the
variables (genes) selected in the training phase to predict the risk
scores of the patient samples in the test set. In the assessment phase,
the risk scores are used to designate each test sample as either
high-risk or low-risk based on the user-designated cutPoint.
Prediction accuracy is measured by the p-value difference between
groups as calculated through the central chi-square distribution. In
addition, a Kaplan-Meier Survival Analysis Curve illustrating the
difference between risk groups is written to file in the working R
directory. If Cox Proportional Hazards Regression is the desired
univariate ranking algorithm, then calling this function with the
training and testing sets is all that is necessary for a complete
survival analysis run.Raftery, A.E. (1995). Bayesian model selection in social research (with Discussion). Sociological Methodology 1995 (Peter V. Marsden, ed.), pp. 111-196, Cambridge, Mass.: Blackwells.
Volinsky, C., Madigan, D., Raftery, A., and Kronmal, R. (1997) Bayesian Model Averaging in Proprtional Hazard Models: Assessing the Risk of a Stroke. Applied Statistics 46: 433-448.
Yeung, K.Y., Bumgarner, R.E. and Raftery, A.E. (2005) Bayesian Model Averaging: Development of an improved multi-class, gene selection and classification tool for microarray data. Bioinformatics 21: 2394-2402.
iterateBMAsurv.train.wrapper,
iterateBMAsurv.train,
singleGeneCoxph,
predictBicSurv,
predictiveAssessCategory,
trainData,
trainSurv,
trainCens,
testData,
testSurv,
testCenslibrary (BMA)
library(iterativeBMAsurv)
data(trainData)
data(trainSurv)
data(trainCens)
data(testData)
data(testSurv)
data(testCens)
## Use p=10 genes and nbest=5 for fast computation
ret.bma <- iterateBMAsurv.train.predict.assess (train.dat=trainData, test.dat=testData, surv.time.train=trainSurv, surv.time.test=testSurv, cens.vec.train=trainCens, cens.vec.test=testCens, p=10, nbest=5)
## Extract the statistics from this survival analysis run
number.genes <- ret.bma$nvar
number.models <- ret.bma$nmodel
evaluate.success <- ret.bma$statisticsRun the code above in your browser using DataLab