iterateBMAsurv.train, which
repeatedly calls bic.surv from the BMA package
until all variables are exhausted. At the point when this function
is called, the variables in the dataset are assumed to be
pre-sorted by rank.iterateBMAsurv.train.wrapper (x, surv.time, cens.vec, nbest=10,
maxNvar=25, maxIter=200000, thresProbne0=1, verbose=FALSE, suff.string="")bic.surv in the BMA package.
The default is 10.bic.surv from the BMA package.
The default is 25.bic.surv.
The default is 200000.bic.surv. The default
is 1 percent.maxIter is reached or the iterations stop before all variables
are exhausted, -1 is returned. If all variables are exhausted, two items
are returned:bic.survbic.surv returned by the last iteration of
bic.surv. The object of class bic.surv is a list
consisting of the following components:
[object Object],[object Object],[object Object],[object Object],[object Object],[object Object],[object Object],[object Object],[object Object],[object Object],[object Object],[object Object],[object Object],[object Object],[object Object],[object Object]iterateBMAsurv.train, the variables
are assumed to be sorted, and bic.surv is called repeatedly
until all the variables have been exhausted. In the first application
of the bic.surv algorithm, the top maxNvar univariate
ranked genes are used. After each application of the bic.surv
algorithm, the genes with probne0 < thresProbne0
are dropped, and the next univariate ordered genes are added
to the bic.surv window. The function
iterateBMAsurv.train.predict.assess calls SingleGeneCoxph
before calling this function. Using this function directly, users can
experiment with alternative univariate measures.Raftery, A.E. (1995). Bayesian model selection in social research (with Discussion). Sociological Methodology 1995 (Peter V. Marsden, ed.), pp. 111-196, Cambridge, Mass.: Blackwells.
Volinsky, C., Madigan, D., Raftery, A., and Kronmal, R. (1997) Bayesian Model Averaging in Proprtional Hazard Models: Assessing the Risk of a Stroke. Applied Statistics 46: 433-448.
Yeung, K.Y., Bumgarner, R.E. and Raftery, A.E. (2005) Bayesian Model Averaging: Development of an improved multi-class, gene selection and classification tool for microarray data. Bioinformatics 21: 2394-2402.
iterateBMAsurv.train.predict.assess,
iterateBMAsurv.train,
predictiveAssessCategory,
singleGeneCoxph,
trainData,
trainSurv,
trainCenslibrary (BMA)
library(iterativeBMAsurv)
data(trainData)
data(trainSurv)
data(trainCens)
## Training data should be pre-sorted before beginning
## Run iterative bic.surv, using nbest=5 for fast computation
ret.list <- iterateBMAsurv.train.wrapper (x=trainData, surv.time=trainSurv, cens.vec=trainCens, nbest=5)
## Extract the 'bic.surv' object
ret.bma <- ret.list$obj
## Extract the names of the genes from the last iteration of 'bic.surv'
gene.names <- ret.list$curr.namesRun the code above in your browser using DataLab